/*********************************************************************
 *  SPDX-License-Identifier: MIT                                     *
 *  Copyright (C) 2022 by Helge Kortendieck  alan@kasmithee.de       *
 *                                                                   *
 *  This file is part of qaplay.                                     *
 *********************************************************************/
#include "setplaylist.h"

SetPlayList::SetPlayList(QDialog* parent)
	: QDialog(parent)
{
	uispl.setupUi(&wSPl);
	uispl.pb_New->setIcon(QIcon("/usr/share/qaplay/icons/scalable/new.svg"));
	uispl.pb_FileDlg->setIcon(QIcon("/usr/share/qaplay/icons/scalable/open.svg"));
	uispl.pb_Rename->setIcon(QIcon("/usr/share/qaplay/icons/scalable/rename.svg"));
	uispl.pb_SaveAs->setIcon(QIcon("/usr/share/qaplay/icons/scalable/save-as.svg"));
	connect(uispl.pb_Close, SIGNAL(clicked()), this, SLOT(splDlgClose()));
	connect(uispl.pb_New, SIGNAL(clicked()), this, SLOT(splFileNew()));
	connect(uispl.pb_FileDlg, SIGNAL(clicked()), this, SLOT(splFileOpen()));
	connect(uispl.pb_Rename, SIGNAL(clicked()), this, SLOT(splFileRename()));
	connect(uispl.pb_SaveAs, SIGNAL(clicked()), this, SLOT(splFileSaveAs()));
	uispl.pb_Close->setFocus();
}

SetPlayList::~SetPlayList()
{
}

void SetPlayList::splDlgShow(const QString& sSplD)	// show song list, current dir or favourites songs
{
//cout << "SetPlayList - showSpl() reached " << endl;                                               // *****  debug  *****
	splDlgPopPathName(sSplD);

	wSPl.show();
}

void SetPlayList::splDlgClose()
{
	emit sigSplQapDelete();
}

void SetPlayList::splDlgPopPathName(const QString& sSplD2)
{
	sSplFilePathName = sSplD2;
	QFileInfo fi(sSplFilePathName);
		sSplFilePath = fi.absolutePath();
		sSplFileName = fi.baseName();
	uispl.l_FilePath->setText(sSplFilePath);
	uispl.l_FileName->setText(sSplFileName);
}

void SetPlayList::splFileNew()						// create new playlist to add files to
{
	QFileDialog fd(this, tr("Create new, empty playlist"), sSplFilePath, "*.m3u");
		fd.setViewMode(QFileDialog::Detail);
		fd.setFileMode(QFileDialog::AnyFile);
		fd.setDefaultSuffix("m3u");
	
	if (fd.exec()) {
		slSplD = fd.selectedFiles();
	}
	if (slSplD.count() > 0) {							// dialog not canceled
		sSplFileFromDlg = slSplD.at(0);
//cout << "SetPlayList - createNew() : sSplFileName = " << sSplFileName.toStdString() << endl;                                               // *****  debug  *****
		if (sSplFileFromDlg != "") {
			if (m3uFileCreate(sSplFileFromDlg) == "0") {
				QMessageBox msgBox;
					msgBox.setText("It seems, the new playlist could not be create.");
					msgBox.setInformativeText("May be the file exists or a write permission problem?");
					msgBox.exec();
			} else {
				splDlgPopPathName(sSplFileFromDlg);
				emit sigSplQapM3uUpd(sSplFileFromDlg);
//				splDlgClose();								// leave open for feedback ?
			}
		}
	}
}

void SetPlayList::splFileOpen()						// open file dialog to pick an existing playlist to set
{
	sSplFileFromDlg = QFileDialog::getOpenFileName(this, tr("Select existing playlist"), sSplFilePath, "*.m3u");
	if (sSplFileFromDlg != "") {
		splDlgPopPathName(sSplFileFromDlg);
		emit sigSplQapM3uUpd(sSplFileFromDlg);
//		splDlgClose();									// leave open for feedback ?
	}
}

void SetPlayList::splFileRename()					// rename current playlist
{
	QFileDialog fd(this, tr("rename playlist"), sSplFilePath, "*.m3u");
		fd.setViewMode(QFileDialog::Detail);
		fd.setFileMode(QFileDialog::AnyFile);
		fd.selectUrl(QUrl::fromLocalFile(sSplFilePath + "/" + sSplFileName));
		fd.setDefaultSuffix("m3u");

	if (fd.exec() == 1) {
		slSplD = fd.selectedFiles();
	} else {
		return;
	}
	if (slSplD.count() > 0) {
		sSplFileFromDlg = slSplD.at(0);
	} else {
		return;
	}
//cout << "splFileRename - sSplFileRename = " << sSplFileFromDlg.toStdString() << endl;                                               // *****  debug  *****

	QFileInfo fi(sSplFileFromDlg);
	if (fi.exists() == true) {
		QMessageBox msgBox;
			msgBox.setText("Invalid playlist name.");
			msgBox.setInformativeText("A file with this name already exists!");
			msgBox.exec();
		return;
	} else {
		if (m3uFileRename(sSplFilePathName, sSplFileFromDlg) == false) {
			QMessageBox msgBox;
				msgBox.setText("Error renaming playlist.");
				msgBox.setInformativeText("An error occurred while trying to rename the current playlist!");
				msgBox.exec();
			return;
		} else {
			splDlgPopPathName(sSplFileFromDlg);
			emit sigSplQapM3uUpd(sSplFileFromDlg);
		}
	}
}

void SetPlayList::splFileSaveAs()					// save current playlist under different name and start using it as such
{
	QFileDialog fd(this, tr("Create new, empty playlist"), sSplFilePath, "*.m3u");
		fd.setViewMode(QFileDialog::Detail);
		fd.setFileMode(QFileDialog::AnyFile);
		fd.setDefaultSuffix("m3u");
	
	if (fd.exec()) {
		slSplD = fd.selectedFiles();
	}
	sSplFileFromDlg = slSplD.at(0);

	if (sSplFileFromDlg != "") {
		if (m3uFileSaveAs(sSplFilePathName, sSplFileFromDlg) == true) {
			splDlgPopPathName(sSplFileFromDlg);
			emit sigSplQapM3uUpd(sSplFileFromDlg);
//			splDlgClose();								// leave open for feedback ?
		} else {
			QMessageBox msgBox;
				msgBox.setText("It seems, the playlist could not be saved under the new name.");
				msgBox.setInformativeText("May be the file exists or a write permission problem?");
				msgBox.exec();
		}
	}
}
